searchData={"items":[{"type":"module","title":"Fab","doc":"Fab is a lightweight Elixir library for generating fake data.","ref":"Fab.html"},{"type":"module","title":"Philosophy - Fab","doc":"Fab is built with a simple goal: **keep the core small and focused**. Instead\nof bundling massive datasets and every conceivable fake data generator, Fab\nprovides a minimal, fast, and composable foundation for generating common\ndata.\n\nNeed more? Use a use-case specific Fab library or create your own.","ref":"Fab.html#module-philosophy"},{"type":"module","title":"Why Not Include More? - Fab","doc":"Many faker libraries become bloated over time. Fab avoids that by:\n\n- Keeping the core library focused and fast\n- Letting users define their own generators\n- Supporting optional extensions via external packages","ref":"Fab.html#module-why-not-include-more"},{"type":"module","title":"Usage - Fab","doc":"See the individual generator modules for usage examples.\n\n- `Fab.DateTime`\n- `Fab.Number`\n- `Fab.String`","ref":"Fab.html#module-usage"},{"type":"module","title":"Localization - Fab","doc":"Fab supports generating localized fake data. You can set your preferred locale\nusing the `:locale` application configuration:\n\n    config :fab, :locale, :es\n\nIf the specified locale is not implemented, Fab falls back to the `:en`\nlocale by default.","ref":"Fab.html#module-localization"},{"type":"module","title":"Deterministic Values - Fab","doc":"If you need the values returned by Fab to be deterministic specify a `:seed`\nvalue:\n\n    config :fab, :seed, 0\n\n`Fab.Randomizer` functions will use this seed when picking random values.","ref":"Fab.html#module-deterministic-values"},{"type":"module","title":"Official Fab Libraries - Fab","doc":"- [`Fab.Internet`](https://hexdocs.pm/fab_internet)\n- [`Fab.Person`](https://hexdocs.pm/fab_person)\n- [`Fab.Word`](https://hexdocs.pm/fab_word)","ref":"Fab.html#module-official-fab-libraries"},{"type":"function","title":"Fab.locale/0","doc":"Returns the current locale used for generating fake data.","ref":"Fab.html#locale/0"},{"type":"function","title":"Fab.put_locale/1","doc":"Sets the global locale for generating fake data.\n\nUse this when you want Fab to always use the specified locale.","ref":"Fab.html#put_locale/1"},{"type":"function","title":"Fab.set_locale/1","doc":"Sets the locale for generating fake data in the current process.\n\nThis is useful when you need a specific locale for a test or a temporary\ncontext.","ref":"Fab.html#set_locale/1"},{"type":"module","title":"Fab.DateTime","doc":"Functions for generating random `DateTime`'s.","ref":"Fab.DateTime.html"},{"type":"function","title":"Fab.DateTime.anytime/1","doc":"Generates a random date that can be in the past or future.","ref":"Fab.DateTime.html#anytime/1"},{"type":"function","title":"Options - Fab.DateTime.anytime/1","doc":"- `:ref_date` - `DateTime` used as the reference point for the newly generated date. Defaults to `DateTime.utc_now/1`.\n- `:unit` - Time unit used for the generated date. Can be `:microsecond`, `:millisecond`, `:native` or `:second`. Defaults to `:native`.","ref":"Fab.DateTime.html#anytime/1-options"},{"type":"function","title":"Examples - Fab.DateTime.anytime/1","doc":"iex> Fab.DateTime.anytime()\n    ~U[1523-04-23 21:41:18.532309Z]\n\n    iex> Fab.DateTime.anytime(unit: :second)\n    ~U[1965-10-18 11:26:15Z]","ref":"Fab.DateTime.html#anytime/1-examples"},{"type":"function","title":"Fab.DateTime.between/1","doc":"Generates a random date between two dates.","ref":"Fab.DateTime.html#between/1"},{"type":"function","title":"Options - Fab.DateTime.between/1","doc":"- `:from` - `DateTime` used as the early date boundary\n- `:to` - `DateTime` used as the late date boundary\n- `:unit` - Time unit used for the generated date. Can be `:microsecond`, `:millisecond`, `:native` or `:second`. Defaults to `:native`.","ref":"Fab.DateTime.html#between/1-options"},{"type":"function","title":"Examples - Fab.DateTime.between/1","doc":"iex> Fab.DateTime.between(from: ~U[2025-05-04 18:21:38Z], to: ~U[2025-05-05 21:38:40Z])\n    ~U[2025-05-05 21:38:28.112142Z]\n\n    iex> Fab.DateTime.between(from: ~U[2025-05-05 01:57:58Z], to: ~U[2025-05-06 10:34:09Z], unit: :second)\n    ~U[2025-05-05 19:09:21Z]","ref":"Fab.DateTime.html#between/1-examples"},{"type":"type","title":"Fab.DateTime.days_t/0","doc":"","ref":"Fab.DateTime.html#t:days_t/0"},{"type":"type","title":"Fab.DateTime.from_t/0","doc":"","ref":"Fab.DateTime.html#t:from_t/0"},{"type":"function","title":"Fab.DateTime.future/1","doc":"Generates a random date years in the future.","ref":"Fab.DateTime.html#future/1"},{"type":"function","title":"Options - Fab.DateTime.future/1","doc":"- `:ref_date` - `DateTime` used as the reference point for the newly generated date. Defaults to `DateTime.utc_now/1`.\n- `:unit` - Time unit used for the generated date. Can be `:microsecond`, `:millisecond`, `:native` or `:second`. Defaults to `:native`.\n- `:years` - Number of years the date may be in the future. Defaults to `1`.","ref":"Fab.DateTime.html#future/1-options"},{"type":"function","title":"Examples - Fab.DateTime.future/1","doc":"iex> Fab.DateTime.future()\n    ~U[2026-04-07 00:06:12.857101Z]\n\n    iex> Fab.DateTime.future(years: 10)\n    ~U[2028-09-19 10:23:55.939960Z]\n\n    iex> Fab.DateTime.future(unit: :second)\n    ~U[2026-03-24 06:13:08Z]","ref":"Fab.DateTime.html#future/1-examples"},{"type":"function","title":"Fab.DateTime.past/1","doc":"Generates a random date years in the past.","ref":"Fab.DateTime.html#past/1"},{"type":"function","title":"Options - Fab.DateTime.past/1","doc":"- `:ref_date` - `DateTime` used as the reference point for the newly generated date. Defaults to `DateTime.utc_now/1`.\n- `:unit` - Time unit used for the generated date. Can be `:microsecond`, `:millisecond`, `:native` or `:second`. Defaults to `:native`.\n- `:years` - Number of years the date may be in the past. Defaults to `1`.","ref":"Fab.DateTime.html#past/1-options"},{"type":"function","title":"Examples - Fab.DateTime.past/1","doc":"iex> Fab.DateTime.past()\n    ~U[2025-01-24 16:01:23.564206Z]\n\n    iex> Fab.DateTime.past(years: 10)\n    ~U[2023-04-24 03:50:54.545857Z]\n\n    iex> Fab.DateTime.past(unit: :second)\n    ~U[2024-07-30 14:33:43Z]","ref":"Fab.DateTime.html#past/1-examples"},{"type":"function","title":"Fab.DateTime.recent/1","doc":"Generates a random date days in the past.","ref":"Fab.DateTime.html#recent/1"},{"type":"function","title":"Options - Fab.DateTime.recent/1","doc":"- `:days` - Number of days the date may be in the past. Defaults to `1`.\n- `:ref_date` - `DateTime` used as the reference point for the newly generated date. Defaults to `DateTime.utc_now/1`.\n- `:unit` - Time unit used for the generated date. Can be `:microsecond`, `:millisecond`, `:native` or `:second`. Defaults to `:native`.","ref":"Fab.DateTime.html#recent/1-options"},{"type":"function","title":"Examples - Fab.DateTime.recent/1","doc":"iex> Fab.DateTime.recent()\n    ~U[2025-05-05 04:53:03.098150Z]\n\n    iex> Fab.DateTime.recent(days: 10)\n    ~U[2025-05-03 21:37:48.405103Z]\n\n    iex> Fab.DateTime.recent(unit: :second)\n    ~U[2025-05-05 16:44:47Z]","ref":"Fab.DateTime.html#recent/1-examples"},{"type":"type","title":"Fab.DateTime.ref_date_t/0","doc":"","ref":"Fab.DateTime.html#t:ref_date_t/0"},{"type":"function","title":"Fab.DateTime.soon/1","doc":"Generates a random date days in the future.","ref":"Fab.DateTime.html#soon/1"},{"type":"function","title":"Options - Fab.DateTime.soon/1","doc":"- `:days` - Number of days the date may be in the future. Defaults to `1`.\n- `:ref_date` - `DateTime` used as the reference point for the newly generated date. Defaults to `DateTime.utc_now/1`.\n- `:unit` - Time unit used for the generated date. Can be `:microsecond`, `:millisecond`, `:native` or `:second`. Defaults to `:native`.","ref":"Fab.DateTime.html#soon/1-options"},{"type":"function","title":"Examples - Fab.DateTime.soon/1","doc":"iex> Fab.DateTime.soon()\n    ~U[2025-05-05 19:38:07.213655Z]\n\n    iex> Fab.DateTime.soon(days: 10)\n    ~U[2025-05-12 08:56:42.439410Z]\n\n    iex> Fab.DateTime.soon(unit: :second)\n    ~U[2025-05-06 11:10:33Z]","ref":"Fab.DateTime.html#soon/1-examples"},{"type":"type","title":"Fab.DateTime.to_t/0","doc":"","ref":"Fab.DateTime.html#t:to_t/0"},{"type":"type","title":"Fab.DateTime.unit_t/0","doc":"","ref":"Fab.DateTime.html#t:unit_t/0"},{"type":"type","title":"Fab.DateTime.years_t/0","doc":"","ref":"Fab.DateTime.html#t:years_t/0"},{"type":"module","title":"Fab.Locale","doc":"Provides dynamic function dispatch based on the current locale.","ref":"Fab.Locale.html"},{"type":"function","title":"Fab.Locale.localize/3","doc":"Dynamically resolves and invokes a localized implementation of a given\nfunction.\n\nConstructs a module path based on the current locale by inserting the locale\nbetween the root and the provider module segments. Then attempts to load and\ninvoke the specified function from this localized module. If the localized\nmodule or function is unavailable, falls back to using the English version of\nthe module.","ref":"Fab.Locale.html#localize/3"},{"type":"function","title":"Example - Fab.Locale.localize/3","doc":"iex> Fab.set_locale(:es)\n    ...> Fab.Locale.localize(Fab.MyMod, :rando, [])\n\nThis would resolve to:\n\n  - `Fab.Es.MyMod.rando/0`\n  - or `Fab.En.MyMod.rando/0` if the localized implementation does not exist","ref":"Fab.Locale.html#localize/3-example"},{"type":"module","title":"Fab.Number","doc":"Functions for generating random numbers.","ref":"Fab.Number.html"},{"type":"function","title":"Fab.Number.float/1","doc":"Returns a random float.","ref":"Fab.Number.html#float/1"},{"type":"function","title":"Options - Fab.Number.float/1","doc":"- `:min` - Lower bound of the generated float. Defaults to `0.0`.\n- `:max` - Upper bound of the generated float. Defaults to `1.0`.\n- `:precision` - Number of digits after the decimal point. Defaults to `1`.","ref":"Fab.Number.html#float/1-options"},{"type":"function","title":"Examples - Fab.Number.float/1","doc":"iex> Fab.Number.float()\n    0.2\n\n    iex> Fab.Number.float(5.0)\n    1.1\n\n    iex> Fab.Number.float(min: 1.0, max: 2.0)\n    1.2\n\n    iex> Fab.Number.float(precision: 3)\n    0.217","ref":"Fab.Number.html#float/1-examples"},{"type":"function","title":"Fab.Number.hex/1","doc":"Returns a random hexadecimal.","ref":"Fab.Number.html#hex/1"},{"type":"function","title":"Options - Fab.Number.hex/1","doc":"- `:min` - Lower bound of the generated hexadecimal. Defaults to `0`.\n- `:max` - Lower bound of the generated hexadecimal. Defaults to `15`.","ref":"Fab.Number.html#hex/1-options"},{"type":"function","title":"Examples - Fab.Number.hex/1","doc":"iex> Fab.Number.hex()\n    \"F\"\n\n    iex> Fab.Number.hex(255)\n    \"7F\"\n\n    iex> Fab.Number.hex(min: 0, max: 65535)\n    \"467F\"","ref":"Fab.Number.html#hex/1-examples"},{"type":"function","title":"Fab.Number.integer/1","doc":"Returns a random integer.","ref":"Fab.Number.html#integer/1"},{"type":"function","title":"Options - Fab.Number.integer/1","doc":"- `:min` - Lower bound of the generated integer. Defaults to `0`.\n- `:max` - Upper bound of the generated integer. Defaults to\n  `9007199254740991`.","ref":"Fab.Number.html#integer/1-options"},{"type":"function","title":"Examples - Fab.Number.integer/1","doc":"iex> Fab.Number.integer()\n    3630114979716424\n\n    iex> Fab.Number.integer(1000)\n    340\n\n    iex> Fab.Number.integer(min: 1, max: 1000)\n    185","ref":"Fab.Number.html#integer/1-examples"},{"type":"module","title":"Fab.Randomizer","doc":"Functions for choosing or generating random values.\n\nThe functions in this module are primarily used when implementing a generator\nmodule.","ref":"Fab.Randomizer.html"},{"type":"function","title":"Fab.Randomizer.random/1","doc":"","ref":"Fab.Randomizer.html#random/1"},{"type":"function","title":"Fab.Randomizer.uniform/0","doc":"","ref":"Fab.Randomizer.html#uniform/0"},{"type":"module","title":"Fab.String","doc":"Functions for generating random strings.","ref":"Fab.String.html"},{"type":"function","title":"Fab.String.alpha/1","doc":"Returns a random string consisting of letters from the English alphabet.","ref":"Fab.String.html#alpha/1"},{"type":"function","title":"Options - Fab.String.alpha/1","doc":"- `:case` - Case of the characters. Can be `:lower`, `:mixed` or `:upper`.\n  Defaults to `:mixed`.\n- `:exclude` - List of characters to exclude from the result\n- `:min` - Minimum number of characters to generate\n- `:max` - Maximum number of characters to generate","ref":"Fab.String.html#alpha/1-options"},{"type":"function","title":"Examples - Fab.String.alpha/1","doc":"iex> Fab.String.alpha()\n    \"b\"\n\n    iex> Fab.String.alpha(5)\n    \"beTko\"\n\n    iex> Fab.String.alpha(case: :lower)\n    \"b\"\n\n    iex> Fab.String.alpha(case: :upper)\n    \"B\"\n\n    iex> Fab.String.alpha(exclude: [\"j\"])\n    \"h\"\n\n    iex> Fab.String.alpha(min: 5, max: 10)\n    \"beTkoB\"","ref":"Fab.String.html#alpha/1-examples"},{"type":"function","title":"Fab.String.alphanumeric/1","doc":"Returns a random string consisting of numbers and letters from the English\nalphabet.","ref":"Fab.String.html#alphanumeric/1"},{"type":"function","title":"Options - Fab.String.alphanumeric/1","doc":"- `:case` - Case of the characters. Can be `:lower`, `:mixed` or `:upper`.\n  Defaults to `:mixed`.\n- `:exclude` - List of characters to exclude from the result\n- `:min` - Minimum number of characters to generate\n- `:max` - Maximum number of characters to generate","ref":"Fab.String.html#alphanumeric/1-options"},{"type":"function","title":"Examples - Fab.String.alphanumeric/1","doc":"iex> Fab.String.alphanumeric()\n    \"c\"\n\n    iex> Fab.String.alphanumeric(5)\n    \"cuCMf\"\n\n    iex> Fab.String.alphanumeric(case: :lower)\n    \"6\"\n\n    iex> Fab.String.alphanumeric(case: :upper)\n    \"6\"\n\n    iex> Fab.String.alphanumeric(exclude: [\"q\"])\n    \"Z\"\n\n    iex> Fab.String.alphanumeric(min: 5, max: 10)\n    \"cuCMf7jVfe\"","ref":"Fab.String.html#alphanumeric/1-examples"},{"type":"function","title":"Fab.String.any/1","doc":"Returns a random string consisting of symbols, numbers and letters from the\nEnglish alphabet.","ref":"Fab.String.html#any/1"},{"type":"function","title":"Options - Fab.String.any/1","doc":"- `:case` - Case of the characters. Can be `:lower`, `:mixed` or `:upper`.\n  Defaults to `:mixed`.\n- `:exclude` - List of characters to exclude from the result\n- `:min` - Minimum number of characters to generate\n- `:max` - Maximum number of characters to generate","ref":"Fab.String.html#any/1-options"},{"type":"function","title":"Examples - Fab.String.any/1","doc":"iex> Fab.String.any()\n    \"`\"\n\n    iex> Fab.String.any(5)\n    \"`>9k@\"\n\n    iex> Fab.String.any(case: :lower)\n    \"9\"\n\n    iex> Fab.String.any(case: :upper)\n    \"9\"\n\n    iex> Fab.String.any(exclude: [\"&\"])\n    \"u\"\n\n    iex> Fab.String.any(min: 5, max: 10)\n    \"`>9k@*5'b\"","ref":"Fab.String.html#any/1-examples"},{"type":"type","title":"Fab.String.case_t/0","doc":"","ref":"Fab.String.html#t:case_t/0"},{"type":"type","title":"Fab.String.exclude_t/0","doc":"","ref":"Fab.String.html#t:exclude_t/0"},{"type":"function","title":"Fab.String.from_characters/2","doc":"Returns a random string from the given characters.","ref":"Fab.String.html#from_characters/2"},{"type":"function","title":"Options - Fab.String.from_characters/2","doc":"- `:min` - Minimum number of characters to generate\n- `:max` - Maximum number of characters to generate","ref":"Fab.String.html#from_characters/2-options"},{"type":"function","title":"Examples - Fab.String.from_characters/2","doc":"iex> Fab.String.from_characters([\"a\", \"b\", \"c\"])\n    \"a\"\n\n    iex> Fab.String.from_characters(\"abc\")\n    \"a\"\n\n    iex> Fab.String.from_characters(\"abc\", 5)\n    \"abbba\"\n\n    iex> Fab.String.from_characters(\"abc\", min: 5, max: 10)\n    \"abbbaca\"","ref":"Fab.String.html#from_characters/2-examples"},{"type":"type","title":"Fab.String.max_t/0","doc":"","ref":"Fab.String.html#t:max_t/0"},{"type":"type","title":"Fab.String.min_t/0","doc":"","ref":"Fab.String.html#t:min_t/0"},{"type":"function","title":"Fab.String.numeric/1","doc":"Returns a random string consisting of numbers.","ref":"Fab.String.html#numeric/1"},{"type":"function","title":"Options - Fab.String.numeric/1","doc":"- `:exclude` - List of characters to exclude from the result\n- `:min` - Minimum number of characters to generate\n- `:max` - Maximum number of characters to generate","ref":"Fab.String.html#numeric/1-options"},{"type":"function","title":"Examples - Fab.String.numeric/1","doc":"iex> Fab.String.numeric()\n    \"4\"\n\n    iex> Fab.String.numeric(5)\n    \"40427\"\n\n    iex> Fab.String.numeric(exclude: [\"1\"])\n    \"6\"\n\n    iex> Fab.String.numeric(min: 5, max: 10)\n    \"4042773592\"","ref":"Fab.String.html#numeric/1-examples"},{"type":"function","title":"Fab.String.symbol/1","doc":"Returns a random string consisting of ASCII symbol characters.","ref":"Fab.String.html#symbol/1"},{"type":"function","title":"Symbols - Fab.String.symbol/1","doc":"```\n! \" # $ % & ' ( ) * + , - . / : ; < = > ? @ [ \\ ] ^ _ ` { | } ~\n```","ref":"Fab.String.html#symbol/1-symbols"},{"type":"function","title":"Options - Fab.String.symbol/1","doc":"- `:exclude` - List of characters to exclude from the result\n- `:min` - Minimum number of characters to generate\n- `:max` - Maximum number of characters to generate","ref":"Fab.String.html#symbol/1-options"},{"type":"function","title":"Examples - Fab.String.symbol/1","doc":"iex> Fab.String.symbol()\n    \"}\"\n\n    iex> Fab.String.symbol(5)\n    \"}&$^!\"\n\n    iex> Fab.String.symbol(exclude: [\"!\"])\n    \"(\"\n\n    iex> Fab.String.symbol(min: 5, max: 10)\n    \"}&$^!]?)`\"","ref":"Fab.String.html#symbol/1-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}